@@ -25,7 +25,7 @@
 #include "globals.h"
 
 SDL_Surface *screen;
-SDL_Surface *background;
+FrameSeq *background;
 
 ScreenFont *cga, *cgaInv;
 
@@ -34,12 +34,10 @@ const SDL_VideoInfo *videoinfo;
 
 MenuRoot *mroot;
 
-ControlsArray *controlsArray;
-Configuration configuration;
+ControlsArray *controlsArray = NULL;
 
 #ifndef NONET
 NetServer * nets = NULL;
 NetClient * netc = NULL;
 #endif
 
-Aargh aargh;
